.. currentmodule:: cratermaker

.. image:: ../_static/index_gallery.svg
    :alt: Examples
    :align: center
    :width: 300px


###############
Example Gallery
###############

Below you will find a selection of examples that demonstrate how to use Cratermaker. The gallery is organized by the main components of Cratermaker. Each example is fully working and can be run directly.